@@ -2,42 +2,36 @@ import tempfile
 from pathlib import Path
 
 import pytest
-from ape.exceptions import ContractLogicError, SignatureError
-from ape.utils import DEFAULT_TEST_MNEMONIC
-from evm_trace import CallTreeNode, CallType, TraceFrame
+from ape.api import ReceiptAPI
+from ape.exceptions import ContractLogicError
+from ape.types import CallTreeNode, TraceFrame
+from evm_trace import CallType
 from hexbytes import HexBytes
 
 from ape_hardhat.exceptions import HardhatProviderError
-from ape_hardhat.provider import HARDHAT_CHAIN_ID, HARDHAT_CONFIG_FILE_NAME
+from ape_hardhat.provider import HARDHAT_CHAIN_ID
 
 TEST_WALLET_ADDRESS = "0xD9b7fdb3FC0A0Aa3A507dCf0976bc23D49a9C7A3"
 
 
-def test_instantiation(disconnected_provider):
-    assert disconnected_provider.name == "hardhat"
+def test_instantiation(disconnected_provider, name):
+    assert disconnected_provider.name == name
 
 
-def test_connect_and_disconnect(create_provider):
+def test_connect_and_disconnect(disconnected_provider):
     # Use custom port to prevent connecting to a port used in another test.
 
-    provider = create_provider()
-    provider.port = 8555
-    provider.connect()
-
-    # Verify config file got created
-    config = Path(HARDHAT_CONFIG_FILE_NAME)
-    config_text = config.read_text()
-    assert config.exists()
-    assert DEFAULT_TEST_MNEMONIC in config_text
+    disconnected_provider.port = 8555
+    disconnected_provider.connect()
 
     try:
-        assert provider.is_connected
-        assert provider.chain_id == HARDHAT_CHAIN_ID
+        assert disconnected_provider.is_connected
+        assert disconnected_provider.chain_id == HARDHAT_CHAIN_ID
     finally:
-        provider.disconnect()
+        disconnected_provider.disconnect()
 
-    assert not provider.is_connected
-    assert provider.process is None
+    assert not disconnected_provider.is_connected
+    assert disconnected_provider.process is None
 
 
 def test_gas_price(connected_provider):
@@ -46,50 +40,17 @@ def test_gas_price(connected_provider):
 
 
 def test_uri_disconnected(disconnected_provider):
-    with pytest.raises(HardhatProviderError) as err:
+    with pytest.raises(
+        HardhatProviderError, match=r"Can't build URI before `connect\(\)` is called\."
+    ):
         _ = disconnected_provider.uri
 
-    assert "Can't build URI before `connect()` is called." in str(err.value)
-
 
 def test_uri(connected_provider):
     expected_uri = f"http://127.0.0.1:{connected_provider.port}"
     assert expected_uri in connected_provider.uri
 
 
-def test_multiple_instances(create_provider):
-    """
-    Validate the somewhat tricky internal logic of running multiple Hardhat subprocesses
-    under a single parent process.
-    """
-    # instantiate the providers (which will start the subprocesses) and validate the ports
-    provider_1 = create_provider()
-    provider_2 = create_provider()
-    provider_3 = create_provider()
-    provider_1.port = 8556
-    provider_2.port = 8557
-    provider_3.port = 8558
-    provider_1.connect()
-    provider_2.connect()
-    provider_3.connect()
-
-    # The web3 clients must be different in the HH provider instances (compared to the
-    # behavior of the EthereumProvider base class, where it's a shared classvar)
-    assert provider_1._web3 != provider_2._web3 != provider_3._web3
-
-    assert provider_1.port == 8556
-    assert provider_2.port == 8557
-    assert provider_3.port == 8558
-
-    provider_1.mine()
-    provider_2.mine()
-    provider_3.mine()
-    hash_1 = provider_1.get_block("latest").hash
-    hash_2 = provider_2.get_block("latest").hash
-    hash_3 = provider_3.get_block("latest").hash
-    assert hash_1 != hash_2 != hash_3
-
-
 def test_set_block_gas_limit(connected_provider):
     gas_limit = connected_provider.get_block("latest").gas_limit
     assert connected_provider.set_block_gas_limit(gas_limit) is True
@@ -160,31 +121,27 @@ def test_get_call_tree(connected_provider, sender, receiver):
     transfer = sender.transfer(receiver, 1)
     call_tree = connected_provider.get_call_tree(transfer.txn_hash)
     assert isinstance(call_tree, CallTreeNode)
-    assert call_tree.call_type == CallType.CALL
-    assert repr(call_tree) == "CALL: 0xc89D42189f0450C2b2c3c61f58Ec5d628176A1E7 [0 gas]"
+    assert call_tree.call_type == CallType.CALL.value
+    assert repr(call_tree) == "0xc89D42189f0450C2b2c3c61f58Ec5d628176A1E7.0x()"
 
 
-def test_request_timeout(connected_provider, config, create_provider):
+def test_request_timeout(connected_provider, config):
+    # Test value set in `ape-config.yaml`
+    expected = 29
     actual = connected_provider.web3.provider._request_kwargs["timeout"]
-    expected = 29  # Value set in `ape-config.yaml`
     assert actual == expected
 
     # Test default behavior
     with tempfile.TemporaryDirectory() as temp_dir_str:
         temp_dir = Path(temp_dir_str)
         with config.using_project(temp_dir):
-            provider = create_provider()
-            assert provider.timeout == 30
+            assert connected_provider.timeout == 30
 
 
 def test_send_transaction(contract_instance, owner):
     contract_instance.setNumber(10, sender=owner)
     assert contract_instance.myNumber() == 10
 
-    # Have to be in the same test because of X-dist complications
-    with pytest.raises(SignatureError):
-        contract_instance.setNumber(20)
-
 
 def test_contract_revert_no_message(owner, contract_instance):
     # The Contract raises empty revert when setting number to 5.
@@ -221,6 +178,7 @@ def test_set_code(connected_provider, contract_instance):
 
 def test_return_value(connected_provider, contract_instance, owner):
     receipt = contract_instance.setAddress(owner.address, sender=owner)
+    assert isinstance(receipt, ReceiptAPI)
     assert receipt.return_value == 123
 
 
